@@ -1,5 +1,7 @@
 # all modules
 from . import knn
+from . import utils
+from . import classes
 
 # version
 __version__ = "0.0.1"
\ No newline at end of file
